"""Smoke tests for src/pact/schemas_tasks.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_schemas_tasks():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.schemas_tasks")
    assert mod is not None
